Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1Feature

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb

Overview

The type of Google Cloud Vision API detection to perform, and the maximum number of results to return for that type. Multiple Feature objects can be specified in the features list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1Feature

Returns a new instance of GoogleCloudVisionV1p1beta1Feature.



1873
1874
1875
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 1873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_resultsFixnum

Maximum number of results of this type. Does not apply to TEXT_DETECTION, DOCUMENT_TEXT_DETECTION, or CROP_HINTS. Corresponds to the JSON property maxResults

Returns:

  • (Fixnum)


1859
1860
1861
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 1859

def max_results
  @max_results
end

#modelString

Model to use for the feature. Supported values: "builtin/stable" (the default if unset) and "builtin/latest". DOCUMENT_TEXT_DETECTION and TEXT_DETECTION also support "builtin/rc" for the latest release candidate. Corresponds to the JSON property model

Returns:

  • (String)


1866
1867
1868
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 1866

def model
  @model
end

#typeString

The feature type. Corresponds to the JSON property type

Returns:

  • (String)


1871
1872
1873
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 1871

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1878
1879
1880
1881
1882
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 1878

def update!(**args)
  @max_results = args[:max_results] if args.key?(:max_results)
  @model = args[:model] if args.key?(:model)
  @type = args[:type] if args.key?(:type)
end