Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1LatLongRect
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1LatLongRect
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb
Overview
Rectangle determined by min and max LatLng pairs.
Instance Attribute Summary collapse
-
#max_lat_lng ⇒ Google::Apis::VisionV1p1beta1::LatLng
An object that represents a latitude/longitude pair.
-
#min_lat_lng ⇒ Google::Apis::VisionV1p1beta1::LatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1LatLongRect
constructor
A new instance of GoogleCloudVisionV1p1beta1LatLongRect.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1LatLongRect
Returns a new instance of GoogleCloudVisionV1p1beta1LatLongRect.
2164 2165 2166 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_lat_lng ⇒ Google::Apis::VisionV1p1beta1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property maxLatLng
2154 2155 2156 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2154 def max_lat_lng @max_lat_lng end |
#min_lat_lng ⇒ Google::Apis::VisionV1p1beta1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property minLatLng
2162 2163 2164 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2162 def min_lat_lng @min_lat_lng end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2169 2170 2171 2172 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2169 def update!(**args) @max_lat_lng = args[:max_lat_lng] if args.key?(:max_lat_lng) @min_lat_lng = args[:min_lat_lng] if args.key?(:min_lat_lng) end |