Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1Product

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb

Overview

A Product contains ReferenceImages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1Product

Returns a new instance of GoogleCloudVisionV1p1beta1Product.



2486
2487
2488
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

User-provided metadata to be stored with this product. Must be at most 4096 characters long. Corresponds to the JSON property description

Returns:

  • (String)


2452
2453
2454
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2452

def description
  @description
end

#display_nameString

The user-provided name for this Product. Must not be empty. Must be at most 4096 characters long. Corresponds to the JSON property displayName

Returns:

  • (String)


2458
2459
2460
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2458

def display_name
  @display_name
end

#nameString

The resource name of the product. Format is: projects/PROJECT_ID/locations/ LOC_ID/products/PRODUCT_ID. This field is ignored when creating a product. Corresponds to the JSON property name

Returns:

  • (String)


2464
2465
2466
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2464

def name
  @name
end

#product_categoryString

Immutable. The category for the product identified by the reference image. This should be one of "homegoods-v2", "apparel-v2", "toys-v2", "packagedgoods- v1" or "general-v1". The legacy categories "homegoods", "apparel", and "toys" are still supported, but these should not be used for new products. Corresponds to the JSON property productCategory

Returns:

  • (String)


2472
2473
2474
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2472

def product_category
  @product_category
end

#product_labelsArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1ProductKeyValue>

Key-value pairs that can be attached to a product. At query time, constraints can be specified based on the product_labels. Note that integer values can be provided as strings, e.g. "1199". Only strings with integer values can match a range-based restriction which is to be supported soon. Multiple values can be assigned to the same key. One product may have up to 500 product_labels. Notice that the total number of distinct product_labels over all products in one ProductSet cannot exceed 1M, otherwise the product search pipeline will refuse to work for that ProductSet. Corresponds to the JSON property productLabels



2484
2485
2486
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2484

def product_labels
  @product_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2491
2492
2493
2494
2495
2496
2497
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2491

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @product_category = args[:product_category] if args.key?(:product_category)
  @product_labels = args[:product_labels] if args.key?(:product_labels)
end