Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1WebDetectionWebPage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb

Overview

Metadata for web pages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1WebDetectionWebPage

Returns a new instance of GoogleCloudVisionV1p1beta1WebDetectionWebPage.



3189
3190
3191
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_matching_imagesArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1WebDetectionWebImage>

Fully matching images on the page. Can include resized copies of the query image. Corresponds to the JSON property fullMatchingImages



3165
3166
3167
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3165

def full_matching_images
  @full_matching_images
end

#page_titleString

Title for the web page, may contain HTML markups. Corresponds to the JSON property pageTitle

Returns:

  • (String)


3170
3171
3172
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3170

def page_title
  @page_title
end

#partial_matching_imagesArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1WebDetectionWebImage>

Partial matching images on the page. Those images are similar enough to share some key-point features. For example an original image will likely have partial matching for its crops. Corresponds to the JSON property partialMatchingImages



3177
3178
3179
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3177

def partial_matching_images
  @partial_matching_images
end

#scoreFloat

(Deprecated) Overall relevancy score for the web page. Corresponds to the JSON property score

Returns:

  • (Float)


3182
3183
3184
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3182

def score
  @score
end

#urlString

The result web page URL. Corresponds to the JSON property url

Returns:

  • (String)


3187
3188
3189
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3187

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3194
3195
3196
3197
3198
3199
3200
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3194

def update!(**args)
  @full_matching_images = args[:full_matching_images] if args.key?(:full_matching_images)
  @page_title = args[:page_title] if args.key?(:page_title)
  @partial_matching_images = args[:partial_matching_images] if args.key?(:partial_matching_images)
  @score = args[:score] if args.key?(:score)
  @url = args[:url] if args.key?(:url)
end