Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1AnnotateFileResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb

Overview

Response to a single file annotation request. A file may contain one or more images, which individually have their own responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1AnnotateFileResponse

Returns a new instance of GoogleCloudVisionV1p2beta1AnnotateFileResponse.



3272
3273
3274
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::VisionV1p1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3254
3255
3256
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3254

def error
  @error
end

#input_configGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1InputConfig

The desired input location and metadata. Corresponds to the JSON property inputConfig



3259
3260
3261
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3259

def input_config
  @input_config
end

#responsesArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1AnnotateImageResponse>

Individual responses to images found within the file. This field will be empty if the error field is set. Corresponds to the JSON property responses



3265
3266
3267
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3265

def responses
  @responses
end

#total_pagesFixnum

This field gives the total number of pages in the file. Corresponds to the JSON property totalPages

Returns:

  • (Fixnum)


3270
3271
3272
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3270

def total_pages
  @total_pages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3277
3278
3279
3280
3281
3282
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3277

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @input_config = args[:input_config] if args.key?(:input_config)
  @responses = args[:responses] if args.key?(:responses)
  @total_pages = args[:total_pages] if args.key?(:total_pages)
end