Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1AnnotateImageResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb

Overview

Response to an image annotation request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1AnnotateImageResponse

Returns a new instance of GoogleCloudVisionV1p2beta1AnnotateImageResponse.



3372
3373
3374
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1ImageAnnotationContext

If an image was produced from a file (e.g. a PDF), this message gives information about the source of that image. Corresponds to the JSON property context



3293
3294
3295
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3293

def context
  @context
end

#crop_hints_annotationGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1CropHintsAnnotation

Set of crop hints that are used to generate new crops when serving images. Corresponds to the JSON property cropHintsAnnotation



3298
3299
3300
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3298

def crop_hints_annotation
  @crop_hints_annotation
end

#errorGoogle::Apis::VisionV1p1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3308
3309
3310
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3308

def error
  @error
end

#face_annotationsArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1FaceAnnotation>

If present, face detection has completed successfully. Corresponds to the JSON property faceAnnotations



3313
3314
3315
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3313

def face_annotations
  @face_annotations
end

#full_text_annotationGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1TextAnnotation

TextAnnotation contains a structured representation of OCR extracted text. The hierarchy of an OCR extracted text structure is like this: TextAnnotation -> Page -> Block -> Paragraph -> Word -> Symbol Each structural component, starting from Page, may further have their own properties. Properties describe detected languages, breaks etc.. Please refer to the TextAnnotation. TextProperty message definition below for more detail. Corresponds to the JSON property fullTextAnnotation



3323
3324
3325
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3323

def full_text_annotation
  @full_text_annotation
end

#image_properties_annotationGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1ImageProperties

Stores image properties, such as dominant colors. Corresponds to the JSON property imagePropertiesAnnotation



3328
3329
3330
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3328

def image_properties_annotation
  @image_properties_annotation
end

#label_annotationsArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1EntityAnnotation>

If present, label detection has completed successfully. Corresponds to the JSON property labelAnnotations



3333
3334
3335
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3333

def label_annotations
  @label_annotations
end

#landmark_annotationsArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1EntityAnnotation>

If present, landmark detection has completed successfully. Corresponds to the JSON property landmarkAnnotations



3338
3339
3340
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3338

def landmark_annotations
  @landmark_annotations
end

#localized_object_annotationsArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1LocalizedObjectAnnotation>

If present, localized object detection has completed successfully. This will be sorted descending by confidence score. Corresponds to the JSON property localizedObjectAnnotations



3344
3345
3346
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3344

def localized_object_annotations
  @localized_object_annotations
end

#logo_annotationsArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1EntityAnnotation>

If present, logo detection has completed successfully. Corresponds to the JSON property logoAnnotations



3349
3350
3351
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3349

def logo_annotations
  @logo_annotations
end

#product_search_resultsGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1ProductSearchResults

Results for a product search request. Corresponds to the JSON property productSearchResults



3354
3355
3356
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3354

def product_search_results
  @product_search_results
end

#safe_search_annotationGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1SafeSearchAnnotation

Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence). Corresponds to the JSON property safeSearchAnnotation



3360
3361
3362
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3360

def safe_search_annotation
  @safe_search_annotation
end

#text_annotationsArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1EntityAnnotation>

If present, text (OCR) detection has completed successfully. Corresponds to the JSON property textAnnotations



3365
3366
3367
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3365

def text_annotations
  @text_annotations
end

#web_detectionGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1WebDetection

Relevant information for the image from the Internet. Corresponds to the JSON property webDetection



3370
3371
3372
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3370

def web_detection
  @web_detection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3377
3378
3379
3380
3381
3382
3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3377

def update!(**args)
  @context = args[:context] if args.key?(:context)
  @crop_hints_annotation = args[:crop_hints_annotation] if args.key?(:crop_hints_annotation)
  @error = args[:error] if args.key?(:error)
  @face_annotations = args[:face_annotations] if args.key?(:face_annotations)
  @full_text_annotation = args[:full_text_annotation] if args.key?(:full_text_annotation)
  @image_properties_annotation = args[:image_properties_annotation] if args.key?(:image_properties_annotation)
  @label_annotations = args[:label_annotations] if args.key?(:label_annotations)
  @landmark_annotations = args[:landmark_annotations] if args.key?(:landmark_annotations)
  @localized_object_annotations = args[:localized_object_annotations] if args.key?(:localized_object_annotations)
  @logo_annotations = args[:logo_annotations] if args.key?(:logo_annotations)
  @product_search_results = args[:product_search_results] if args.key?(:product_search_results)
  @safe_search_annotation = args[:safe_search_annotation] if args.key?(:safe_search_annotation)
  @text_annotations = args[:text_annotations] if args.key?(:text_annotations)
  @web_detection = args[:web_detection] if args.key?(:web_detection)
end