Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1EntityAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb

Overview

Set of detected entity features.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1EntityAnnotation

Returns a new instance of GoogleCloudVisionV1p2beta1EntityAnnotation.



3711
3712
3713
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3711

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_polyGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1BoundingPoly

A bounding polygon for the detected image annotation. Corresponds to the JSON property boundingPoly



3655
3656
3657
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3655

def bounding_poly
  @bounding_poly
end

#confidenceFloat

Deprecated. Use score instead. The accuracy of the entity detection in an image. For example, for an image in which the "Eiffel Tower" entity is detected, this field represents the confidence that there is a tower in the query image. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


3663
3664
3665
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3663

def confidence
  @confidence
end

#descriptionString

Entity textual description, expressed in its locale language. Corresponds to the JSON property description

Returns:

  • (String)


3668
3669
3670
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3668

def description
  @description
end

#localeString

The language code for the locale in which the entity textual description is expressed. Corresponds to the JSON property locale

Returns:

  • (String)


3674
3675
3676
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3674

def locale
  @locale
end

#locationsArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1LocationInfo>

The location information for the detected entity. Multiple LocationInfo elements can be present because one location may indicate the location of the scene in the image, and another location may indicate the location of the place where the image was taken. Location information is usually present for landmarks. Corresponds to the JSON property locations



3683
3684
3685
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3683

def locations
  @locations
end

#midString

Opaque entity ID. Some IDs may be available in Google Knowledge Graph Search API. Corresponds to the JSON property mid

Returns:

  • (String)


3689
3690
3691
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3689

def mid
  @mid
end

#propertiesArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1Property>

Some entities may have optional user-supplied Property (name/value) fields, such a score or string that qualifies the entity. Corresponds to the JSON property properties



3695
3696
3697
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3695

def properties
  @properties
end

#scoreFloat

Overall score of the result. Range [0, 1]. Corresponds to the JSON property score

Returns:

  • (Float)


3700
3701
3702
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3700

def score
  @score
end

#topicalityFloat

The relevancy of the ICA (Image Content Annotation) label to the image. For example, the relevancy of "tower" is likely higher to an image containing the detected "Eiffel Tower" than to an image containing a detected distant towering building, even though the confidence that there is a tower in each image may be the same. Range [0, 1]. Corresponds to the JSON property topicality

Returns:

  • (Float)


3709
3710
3711
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3709

def topicality
  @topicality
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 3716

def update!(**args)
  @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly)
  @confidence = args[:confidence] if args.key?(:confidence)
  @description = args[:description] if args.key?(:description)
  @locale = args[:locale] if args.key?(:locale)
  @locations = args[:locations] if args.key?(:locations)
  @mid = args[:mid] if args.key?(:mid)
  @properties = args[:properties] if args.key?(:properties)
  @score = args[:score] if args.key?(:score)
  @topicality = args[:topicality] if args.key?(:topicality)
end