Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1LocationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb

Overview

Detected entity location information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1LocationInfo

Returns a new instance of GoogleCloudVisionV1p2beta1LocationInfo.



4058
4059
4060
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lat_lngGoogle::Apis::VisionV1p1beta1::LatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property latLng



4056
4057
4058
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4056

def lat_lng
  @lat_lng
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4063
4064
4065
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4063

def update!(**args)
  @lat_lng = args[:lat_lng] if args.key?(:lat_lng)
end