Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1SafeSearchAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb

Overview

Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1SafeSearchAnnotation

Returns a new instance of GoogleCloudVisionV1p2beta1SafeSearchAnnotation.



4560
4561
4562
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adultString

Represents the adult content likelihood for the image. Adult content may contain elements such as nudity, pornographic images or cartoons, or sexual activities. Corresponds to the JSON property adult

Returns:

  • (String)


4533
4534
4535
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4533

def adult
  @adult
end

#medicalString

Likelihood that this is a medical image. Corresponds to the JSON property medical

Returns:

  • (String)


4538
4539
4540
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4538

def medical
  @medical
end

#racyString

Likelihood that the request image contains racy content. Racy content may include (but is not limited to) skimpy or sheer clothing, strategically covered nudity, lewd or provocative poses, or close-ups of sensitive body areas. Corresponds to the JSON property racy

Returns:

  • (String)


4546
4547
4548
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4546

def racy
  @racy
end

#spoofString

Spoof likelihood. The likelihood that an modification was made to the image's canonical version to make it appear funny or offensive. Corresponds to the JSON property spoof

Returns:

  • (String)


4552
4553
4554
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4552

def spoof
  @spoof
end

#violenceString

Likelihood that this image contains violent content. Violent content may include death, serious harm, or injury to individuals or groups of individuals. Corresponds to the JSON property violence

Returns:

  • (String)


4558
4559
4560
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4558

def violence
  @violence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4565
4566
4567
4568
4569
4570
4571
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4565

def update!(**args)
  @adult = args[:adult] if args.key?(:adult)
  @medical = args[:medical] if args.key?(:medical)
  @racy = args[:racy] if args.key?(:racy)
  @spoof = args[:spoof] if args.key?(:spoof)
  @violence = args[:violence] if args.key?(:violence)
end