Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1WebDetectionWebPage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb

Overview

Metadata for web pages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1WebDetectionWebPage

Returns a new instance of GoogleCloudVisionV1p2beta1WebDetectionWebPage.



4913
4914
4915
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_matching_imagesArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1WebDetectionWebImage>

Fully matching images on the page. Can include resized copies of the query image. Corresponds to the JSON property fullMatchingImages



4889
4890
4891
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4889

def full_matching_images
  @full_matching_images
end

#page_titleString

Title for the web page, may contain HTML markups. Corresponds to the JSON property pageTitle

Returns:

  • (String)


4894
4895
4896
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4894

def page_title
  @page_title
end

#partial_matching_imagesArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p2beta1WebDetectionWebImage>

Partial matching images on the page. Those images are similar enough to share some key-point features. For example an original image will likely have partial matching for its crops. Corresponds to the JSON property partialMatchingImages



4901
4902
4903
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4901

def partial_matching_images
  @partial_matching_images
end

#scoreFloat

(Deprecated) Overall relevancy score for the web page. Corresponds to the JSON property score

Returns:

  • (Float)


4906
4907
4908
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4906

def score
  @score
end

#urlString

The result web page URL. Corresponds to the JSON property url

Returns:

  • (String)


4911
4912
4913
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4911

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4918
4919
4920
4921
4922
4923
4924
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 4918

def update!(**args)
  @full_matching_images = args[:full_matching_images] if args.key?(:full_matching_images)
  @page_title = args[:page_title] if args.key?(:page_title)
  @partial_matching_images = args[:partial_matching_images] if args.key?(:partial_matching_images)
  @score = args[:score] if args.key?(:score)
  @url = args[:url] if args.key?(:url)
end