Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1AsyncBatchAnnotateFilesResponse
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1AsyncBatchAnnotateFilesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb
Overview
Response to an async batch file annotation request.
Instance Attribute Summary collapse
-
#responses ⇒ Array<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1AsyncAnnotateFileResponse>
The list of file annotation responses, one for each request in AsyncBatchAnnotateFilesRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p3beta1AsyncBatchAnnotateFilesResponse
constructor
A new instance of GoogleCloudVisionV1p3beta1AsyncBatchAnnotateFilesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p3beta1AsyncBatchAnnotateFilesResponse
Returns a new instance of GoogleCloudVisionV1p3beta1AsyncBatchAnnotateFilesResponse.
5148 5149 5150 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5148 def initialize(**args) update!(**args) end |
Instance Attribute Details
#responses ⇒ Array<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1AsyncAnnotateFileResponse>
The list of file annotation responses, one for each request in
AsyncBatchAnnotateFilesRequest.
Corresponds to the JSON property responses
5146 5147 5148 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5146 def responses @responses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5153 5154 5155 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5153 def update!(**args) @responses = args[:responses] if args.key?(:responses) end |