Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1FaceAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb

Overview

A face annotation object contains the results of face detection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p3beta1FaceAnnotation

Returns a new instance of GoogleCloudVisionV1p3beta1FaceAnnotation.



5571
5572
5573
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anger_likelihoodString

Anger likelihood. Corresponds to the JSON property angerLikelihood

Returns:

  • (String)


5494
5495
5496
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5494

def anger_likelihood
  @anger_likelihood
end

#blurred_likelihoodString

Blurred likelihood. Corresponds to the JSON property blurredLikelihood

Returns:

  • (String)


5499
5500
5501
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5499

def blurred_likelihood
  @blurred_likelihood
end

#bounding_polyGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1BoundingPoly

A bounding polygon for the detected image annotation. Corresponds to the JSON property boundingPoly



5504
5505
5506
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5504

def bounding_poly
  @bounding_poly
end

#detection_confidenceFloat

Detection confidence. Range [0, 1]. Corresponds to the JSON property detectionConfidence

Returns:

  • (Float)


5509
5510
5511
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5509

def detection_confidence
  @detection_confidence
end

#fd_bounding_polyGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1BoundingPoly

A bounding polygon for the detected image annotation. Corresponds to the JSON property fdBoundingPoly



5514
5515
5516
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5514

def fd_bounding_poly
  @fd_bounding_poly
end

#headwear_likelihoodString

Headwear likelihood. Corresponds to the JSON property headwearLikelihood

Returns:

  • (String)


5519
5520
5521
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5519

def headwear_likelihood
  @headwear_likelihood
end

#joy_likelihoodString

Joy likelihood. Corresponds to the JSON property joyLikelihood

Returns:

  • (String)


5524
5525
5526
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5524

def joy_likelihood
  @joy_likelihood
end

#landmarking_confidenceFloat

Face landmarking confidence. Range [0, 1]. Corresponds to the JSON property landmarkingConfidence

Returns:

  • (Float)


5529
5530
5531
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5529

def landmarking_confidence
  @landmarking_confidence
end

#landmarksArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1FaceAnnotationLandmark>

Detected face landmarks. Corresponds to the JSON property landmarks



5534
5535
5536
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5534

def landmarks
  @landmarks
end

#pan_angleFloat

Yaw angle, which indicates the leftward/rightward angle that the face is pointing relative to the vertical plane perpendicular to the image. Range [- 180,180]. Corresponds to the JSON property panAngle

Returns:

  • (Float)


5541
5542
5543
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5541

def pan_angle
  @pan_angle
end

#roll_angleFloat

Roll angle, which indicates the amount of clockwise/anti-clockwise rotation of the face relative to the image vertical about the axis perpendicular to the face. Range [-180,180]. Corresponds to the JSON property rollAngle

Returns:

  • (Float)


5548
5549
5550
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5548

def roll_angle
  @roll_angle
end

#sorrow_likelihoodString

Sorrow likelihood. Corresponds to the JSON property sorrowLikelihood

Returns:

  • (String)


5553
5554
5555
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5553

def sorrow_likelihood
  @sorrow_likelihood
end

#surprise_likelihoodString

Surprise likelihood. Corresponds to the JSON property surpriseLikelihood

Returns:

  • (String)


5558
5559
5560
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5558

def surprise_likelihood
  @surprise_likelihood
end

#tilt_angleFloat

Pitch angle, which indicates the upwards/downwards angle that the face is pointing relative to the image's horizontal plane. Range [-180,180]. Corresponds to the JSON property tiltAngle

Returns:

  • (Float)


5564
5565
5566
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5564

def tilt_angle
  @tilt_angle
end

#under_exposed_likelihoodString

Under-exposed likelihood. Corresponds to the JSON property underExposedLikelihood

Returns:

  • (String)


5569
5570
5571
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5569

def under_exposed_likelihood
  @under_exposed_likelihood
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5576

def update!(**args)
  @anger_likelihood = args[:anger_likelihood] if args.key?(:anger_likelihood)
  @blurred_likelihood = args[:blurred_likelihood] if args.key?(:blurred_likelihood)
  @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly)
  @detection_confidence = args[:detection_confidence] if args.key?(:detection_confidence)
  @fd_bounding_poly = args[:fd_bounding_poly] if args.key?(:fd_bounding_poly)
  @headwear_likelihood = args[:headwear_likelihood] if args.key?(:headwear_likelihood)
  @joy_likelihood = args[:joy_likelihood] if args.key?(:joy_likelihood)
  @landmarking_confidence = args[:landmarking_confidence] if args.key?(:landmarking_confidence)
  @landmarks = args[:landmarks] if args.key?(:landmarks)
  @pan_angle = args[:pan_angle] if args.key?(:pan_angle)
  @roll_angle = args[:roll_angle] if args.key?(:roll_angle)
  @sorrow_likelihood = args[:sorrow_likelihood] if args.key?(:sorrow_likelihood)
  @surprise_likelihood = args[:surprise_likelihood] if args.key?(:surprise_likelihood)
  @tilt_angle = args[:tilt_angle] if args.key?(:tilt_angle)
  @under_exposed_likelihood = args[:under_exposed_likelihood] if args.key?(:under_exposed_likelihood)
end