Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1Page
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1Page
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb
Overview
Detected page from OCR.
Instance Attribute Summary collapse
-
#blocks ⇒ Array<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1Block>
List of blocks of text, images etc on this page.
-
#confidence ⇒ Float
Confidence of the OCR results on the page.
-
#height ⇒ Fixnum
Page height.
-
#property ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1TextAnnotationTextProperty
Additional information detected on the structural component.
-
#width ⇒ Fixnum
Page width.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p3beta1Page
constructor
A new instance of GoogleCloudVisionV1p3beta1Page.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p3beta1Page
Returns a new instance of GoogleCloudVisionV1p3beta1Page.
5975 5976 5977 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5975 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocks ⇒ Array<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1Block>
List of blocks of text, images etc on this page.
Corresponds to the JSON property blocks
5951 5952 5953 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5951 def blocks @blocks end |
#confidence ⇒ Float
Confidence of the OCR results on the page. Range [0, 1].
Corresponds to the JSON property confidence
5956 5957 5958 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5956 def confidence @confidence end |
#height ⇒ Fixnum
Page height. For PDFs the unit is points. For images (including TIFFs) the
unit is pixels.
Corresponds to the JSON property height
5962 5963 5964 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5962 def height @height end |
#property ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p3beta1TextAnnotationTextProperty
Additional information detected on the structural component.
Corresponds to the JSON property property
5967 5968 5969 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5967 def property @property end |
#width ⇒ Fixnum
Page width. For PDFs the unit is points. For images (including TIFFs) the unit
is pixels.
Corresponds to the JSON property width
5973 5974 5975 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5973 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 5980 def update!(**args) @blocks = args[:blocks] if args.key?(:blocks) @confidence = args[:confidence] if args.key?(:confidence) @height = args[:height] if args.key?(:height) @property = args[:property] if args.key?(:property) @width = args[:width] if args.key?(:width) end |