Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p4beta1EntityAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb

Overview

Set of detected entity features.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p4beta1EntityAnnotation

Returns a new instance of GoogleCloudVisionV1p4beta1EntityAnnotation.



7367
7368
7369
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 7367

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_polyGoogle::Apis::VisionV1p1beta1::GoogleCloudVisionV1p4beta1BoundingPoly

A bounding polygon for the detected image annotation. Corresponds to the JSON property boundingPoly



7311
7312
7313
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 7311

def bounding_poly
  @bounding_poly
end

#confidenceFloat

Deprecated. Use score instead. The accuracy of the entity detection in an image. For example, for an image in which the "Eiffel Tower" entity is detected, this field represents the confidence that there is a tower in the query image. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


7319
7320
7321
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 7319

def confidence
  @confidence
end

#descriptionString

Entity textual description, expressed in its locale language. Corresponds to the JSON property description

Returns:

  • (String)


7324
7325
7326
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 7324

def description
  @description
end

#localeString

The language code for the locale in which the entity textual description is expressed. Corresponds to the JSON property locale

Returns:

  • (String)


7330
7331
7332
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 7330

def locale
  @locale
end

#locationsArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p4beta1LocationInfo>

The location information for the detected entity. Multiple LocationInfo elements can be present because one location may indicate the location of the scene in the image, and another location may indicate the location of the place where the image was taken. Location information is usually present for landmarks. Corresponds to the JSON property locations



7339
7340
7341
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 7339

def locations
  @locations
end

#midString

Opaque entity ID. Some IDs may be available in Google Knowledge Graph Search API. Corresponds to the JSON property mid

Returns:

  • (String)


7345
7346
7347
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 7345

def mid
  @mid
end

#propertiesArray<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p4beta1Property>

Some entities may have optional user-supplied Property (name/value) fields, such a score or string that qualifies the entity. Corresponds to the JSON property properties



7351
7352
7353
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 7351

def properties
  @properties
end

#scoreFloat

Overall score of the result. Range [0, 1]. Corresponds to the JSON property score

Returns:

  • (Float)


7356
7357
7358
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 7356

def score
  @score
end

#topicalityFloat

The relevancy of the ICA (Image Content Annotation) label to the image. For example, the relevancy of "tower" is likely higher to an image containing the detected "Eiffel Tower" than to an image containing a detected distant towering building, even though the confidence that there is a tower in each image may be the same. Range [0, 1]. Corresponds to the JSON property topicality

Returns:

  • (Float)


7365
7366
7367
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 7365

def topicality
  @topicality
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 7372

def update!(**args)
  @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly)
  @confidence = args[:confidence] if args.key?(:confidence)
  @description = args[:description] if args.key?(:description)
  @locale = args[:locale] if args.key?(:locale)
  @locations = args[:locations] if args.key?(:locations)
  @mid = args[:mid] if args.key?(:mid)
  @properties = args[:properties] if args.key?(:properties)
  @score = args[:score] if args.key?(:score)
  @topicality = args[:topicality] if args.key?(:topicality)
end