Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p4beta1ReferenceImage
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p4beta1ReferenceImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb
Overview
A ReferenceImage represents a product image and its associated metadata,
such as bounding boxes.
Instance Attribute Summary collapse
-
#bounding_polys ⇒ Array<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p4beta1BoundingPoly>
Optional.
-
#name ⇒ String
The resource name of the reference image.
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p4beta1ReferenceImage
constructor
A new instance of GoogleCloudVisionV1p4beta1ReferenceImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p4beta1ReferenceImage
Returns a new instance of GoogleCloudVisionV1p4beta1ReferenceImage.
8271 8272 8273 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_polys ⇒ Array<Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p4beta1BoundingPoly>
Optional. Bounding polygons around the areas of interest in the reference
image. If this field is empty, the system will try to detect regions of
interest. At most 10 bounding polygons will be used. The provided shape is
converted into a non-rotated rectangle. Once converted, the small edge of the
rectangle must be greater than or equal to 300 pixels. The aspect ratio must
be 1:4 or less (i.e. 1:3 is ok; 1:5 is not).
Corresponds to the JSON property boundingPolys
8256 8257 8258 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8256 def bounding_polys @bounding_polys end |
#name ⇒ String
The resource name of the reference image. Format is: projects/PROJECT_ID/
locations/LOC_ID/products/PRODUCT_ID/referenceImages/IMAGE_ID. This field is
ignored when creating a reference image.
Corresponds to the JSON property name
8263 8264 8265 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8263 def name @name end |
#uri ⇒ String
Required. The Google Cloud Storage URI of the reference image. The URI must
start with gs://.
Corresponds to the JSON property uri
8269 8270 8271 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8269 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8276 8277 8278 8279 8280 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8276 def update!(**args) @bounding_polys = args[:bounding_polys] if args.key?(:bounding_polys) @name = args[:name] if args.key?(:name) @uri = args[:uri] if args.key?(:uri) end |