Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p4beta1SafeSearchAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p4beta1SafeSearchAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb
Overview
Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence).
Instance Attribute Summary collapse
-
#adult ⇒ String
Represents the adult content likelihood for the image.
-
#medical ⇒ String
Likelihood that this is a medical image.
-
#racy ⇒ String
Likelihood that the request image contains racy content.
-
#spoof ⇒ String
Spoof likelihood.
-
#violence ⇒ String
Likelihood that this image contains violent content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p4beta1SafeSearchAnnotation
constructor
A new instance of GoogleCloudVisionV1p4beta1SafeSearchAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p4beta1SafeSearchAnnotation
Returns a new instance of GoogleCloudVisionV1p4beta1SafeSearchAnnotation.
8320 8321 8322 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8320 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adult ⇒ String
Represents the adult content likelihood for the image. Adult content may
contain elements such as nudity, pornographic images or cartoons, or sexual
activities.
Corresponds to the JSON property adult
8293 8294 8295 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8293 def adult @adult end |
#medical ⇒ String
Likelihood that this is a medical image.
Corresponds to the JSON property medical
8298 8299 8300 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8298 def medical @medical end |
#racy ⇒ String
Likelihood that the request image contains racy content. Racy content may
include (but is not limited to) skimpy or sheer clothing, strategically
covered nudity, lewd or provocative poses, or close-ups of sensitive body
areas.
Corresponds to the JSON property racy
8306 8307 8308 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8306 def racy @racy end |
#spoof ⇒ String
Spoof likelihood. The likelihood that an modification was made to the image's
canonical version to make it appear funny or offensive.
Corresponds to the JSON property spoof
8312 8313 8314 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8312 def spoof @spoof end |
#violence ⇒ String
Likelihood that this image contains violent content. Violent content may
include death, serious harm, or injury to individuals or groups of individuals.
Corresponds to the JSON property violence
8318 8319 8320 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8318 def violence @violence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8325 8326 8327 8328 8329 8330 8331 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8325 def update!(**args) @adult = args[:adult] if args.key?(:adult) @medical = args[:medical] if args.key?(:medical) @racy = args[:racy] if args.key?(:racy) @spoof = args[:spoof] if args.key?(:spoof) @violence = args[:violence] if args.key?(:violence) end |