Class: Google::Apis::VisionV1p1beta1::GroupedResult
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p1beta1::GroupedResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb
Overview
Information about the products similar to a single product in a query image.
Instance Attribute Summary collapse
-
#bounding_poly ⇒ Google::Apis::VisionV1p1beta1::BoundingPoly
A bounding polygon for the detected image annotation.
-
#object_annotations ⇒ Array<Google::Apis::VisionV1p1beta1::ObjectAnnotation>
List of generic predictions for the object in the bounding box.
-
#results ⇒ Array<Google::Apis::VisionV1p1beta1::Result>
List of results, one for each product match.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GroupedResult
constructor
A new instance of GroupedResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GroupedResult
Returns a new instance of GroupedResult.
8744 8745 8746 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8744 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_poly ⇒ Google::Apis::VisionV1p1beta1::BoundingPoly
A bounding polygon for the detected image annotation.
Corresponds to the JSON property boundingPoly
8732 8733 8734 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8732 def bounding_poly @bounding_poly end |
#object_annotations ⇒ Array<Google::Apis::VisionV1p1beta1::ObjectAnnotation>
List of generic predictions for the object in the bounding box.
Corresponds to the JSON property objectAnnotations
8737 8738 8739 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8737 def object_annotations @object_annotations end |
#results ⇒ Array<Google::Apis::VisionV1p1beta1::Result>
List of results, one for each product match.
Corresponds to the JSON property results
8742 8743 8744 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8742 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8749 8750 8751 8752 8753 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 8749 def update!(**args) @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly) @object_annotations = args[:object_annotations] if args.key?(:object_annotations) @results = args[:results] if args.key?(:results) end |