Class: Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1ImageContext
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1ImageContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p1beta1/classes.rb,
lib/google/apis/vision_v1p1beta1/representations.rb,
lib/google/apis/vision_v1p1beta1/representations.rb
Overview
Image context and/or feature-specific parameters.
Instance Attribute Summary collapse
-
#crop_hints_params ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1CropHintsParams
Parameters for crop hints annotation request.
-
#language_hints ⇒ Array<String>
List of languages to use for TEXT_DETECTION.
-
#lat_long_rect ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1LatLongRect
Rectangle determined by min and max
LatLngpairs. -
#product_search_params ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1ProductSearchParams
Parameters for a product search request.
-
#text_detection_params ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1TextDetectionParams
Parameters for text detections.
-
#web_detection_params ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1WebDetectionParams
Parameters for web detection request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1ImageContext
constructor
A new instance of GoogleCloudVisionV1p1beta1ImageContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1ImageContext
Returns a new instance of GoogleCloudVisionV1p1beta1ImageContext.
2036 2037 2038 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2036 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crop_hints_params ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1CropHintsParams
Parameters for crop hints annotation request.
Corresponds to the JSON property cropHintsParams
2001 2002 2003 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2001 def crop_hints_params @crop_hints_params end |
#language_hints ⇒ Array<String>
List of languages to use for TEXT_DETECTION. In most cases, an empty value
yields the best results since it enables automatic language detection. For
languages based on the Latin alphabet, setting language_hints is not needed.
In rare cases, when the language of the text in the image is known, setting a
hint will help get better results (although it will be a significant hindrance
if the hint is wrong). Text detection returns an error if one or more of the
specified languages is not one of the supported languages.
Corresponds to the JSON property languageHints
2013 2014 2015 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2013 def language_hints @language_hints end |
#lat_long_rect ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1LatLongRect
Rectangle determined by min and max LatLng pairs.
Corresponds to the JSON property latLongRect
2018 2019 2020 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2018 def lat_long_rect @lat_long_rect end |
#product_search_params ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1ProductSearchParams
Parameters for a product search request.
Corresponds to the JSON property productSearchParams
2023 2024 2025 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2023 def product_search_params @product_search_params end |
#text_detection_params ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1TextDetectionParams
Parameters for text detections. This is used to control TEXT_DETECTION and
DOCUMENT_TEXT_DETECTION features.
Corresponds to the JSON property textDetectionParams
2029 2030 2031 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2029 def text_detection_params @text_detection_params end |
#web_detection_params ⇒ Google::Apis::VisionV1p1beta1::GoogleCloudVisionV1p1beta1WebDetectionParams
Parameters for web detection request.
Corresponds to the JSON property webDetectionParams
2034 2035 2036 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2034 def web_detection_params @web_detection_params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2041 2042 2043 2044 2045 2046 2047 2048 |
# File 'lib/google/apis/vision_v1p1beta1/classes.rb', line 2041 def update!(**args) @crop_hints_params = args[:crop_hints_params] if args.key?(:crop_hints_params) @language_hints = args[:language_hints] if args.key?(:language_hints) @lat_long_rect = args[:lat_long_rect] if args.key?(:lat_long_rect) @product_search_params = args[:product_search_params] if args.key?(:product_search_params) @text_detection_params = args[:text_detection_params] if args.key?(:text_detection_params) @web_detection_params = args[:web_detection_params] if args.key?(:web_detection_params) end |